'use strict';

require('./settings.js');
var color = require('../color.js');
var constants = require('../constants.js');
var extensions = require('../extensions.js');
var _const = require('../math/const.js');
var groupD8 = require('../math/groupD8.js');
var Transform = require('../math/Transform.js');
var runner = require('../runner.js');
require('../ticker/settings.js');
var _const$1 = require('../ticker/const.js');
var Ticker = require('../ticker/Ticker.js');
var TickerPlugin = require('../ticker/TickerPlugin.js');
require('../utils/settings.js');
require('../utils/is_mobile/index.js');
require('../utils/color/premultiply.js');
require('../utils/media/BoundingBox.js');
var autoDetectRenderer = require('./autoDetectRenderer.js');
var BackgroundSystem = require('./background/BackgroundSystem.js');
var BatchRenderer = require('./batch/BatchRenderer.js');
var Program = require('./shader/Program.js');
var BatchSystem = require('./batch/BatchSystem.js');
var ContextSystem = require('./context/ContextSystem.js');
var Filter = require('./filters/Filter.js');
var FilterSystem = require('./filters/FilterSystem.js');
var BaseTexture = require('./textures/BaseTexture.js');
var FramebufferSystem = require('./framebuffer/FramebufferSystem.js');
var MultisampleSystem = require('./framebuffer/MultisampleSystem.js');
var BufferSystem = require('./geometry/BufferSystem.js');
var GeometrySystem = require('./geometry/GeometrySystem.js');
var MaskSystem = require('./mask/MaskSystem.js');
var ScissorSystem = require('./mask/ScissorSystem.js');
var StencilSystem = require('./mask/StencilSystem.js');
var PluginSystem = require('./plugin/PluginSystem.js');
var ProjectionSystem = require('./projection/ProjectionSystem.js');
var ObjectRendererSystem = require('./render/ObjectRendererSystem.js');
var Renderer = require('./Renderer.js');
var GenerateTextureSystem = require('./renderTexture/GenerateTextureSystem.js');
var RenderTexturePool = require('./renderTexture/RenderTexturePool.js');
var RenderTextureSystem = require('./renderTexture/RenderTextureSystem.js');
var ShaderSystem = require('./shader/ShaderSystem.js');
var StartupSystem = require('./startup/StartupSystem.js');
var StateSystem = require('./state/StateSystem.js');
var TextureGCSystem = require('./textures/TextureGCSystem.js');
var TextureSystem = require('./textures/TextureSystem.js');
var TransformFeedbackSystem = require('./transformFeedback/TransformFeedbackSystem.js');
var ViewSystem = require('./view/ViewSystem.js');
require('./textures/resources/index.js');

const VERSION = "$_VERSION";

exports.Color = color.Color;
Object.defineProperty(exports, 'ALPHA_MODES', {
	enumerable: true,
	get: function () { return constants.ALPHA_MODES; }
});
Object.defineProperty(exports, 'BLEND_MODES', {
	enumerable: true,
	get: function () { return constants.BLEND_MODES; }
});
Object.defineProperty(exports, 'BUFFER_BITS', {
	enumerable: true,
	get: function () { return constants.BUFFER_BITS; }
});
Object.defineProperty(exports, 'BUFFER_TYPE', {
	enumerable: true,
	get: function () { return constants.BUFFER_TYPE; }
});
Object.defineProperty(exports, 'CLEAR_MODES', {
	enumerable: true,
	get: function () { return constants.CLEAR_MODES; }
});
Object.defineProperty(exports, 'COLOR_MASK_BITS', {
	enumerable: true,
	get: function () { return constants.COLOR_MASK_BITS; }
});
Object.defineProperty(exports, 'DRAW_MODES', {
	enumerable: true,
	get: function () { return constants.DRAW_MODES; }
});
Object.defineProperty(exports, 'ENV', {
	enumerable: true,
	get: function () { return constants.ENV; }
});
Object.defineProperty(exports, 'FORMATS', {
	enumerable: true,
	get: function () { return constants.FORMATS; }
});
Object.defineProperty(exports, 'GC_MODES', {
	enumerable: true,
	get: function () { return constants.GC_MODES; }
});
Object.defineProperty(exports, 'MASK_TYPES', {
	enumerable: true,
	get: function () { return constants.MASK_TYPES; }
});
Object.defineProperty(exports, 'MIPMAP_MODES', {
	enumerable: true,
	get: function () { return constants.MIPMAP_MODES; }
});
Object.defineProperty(exports, 'MSAA_QUALITY', {
	enumerable: true,
	get: function () { return constants.MSAA_QUALITY; }
});
Object.defineProperty(exports, 'PRECISION', {
	enumerable: true,
	get: function () { return constants.PRECISION; }
});
Object.defineProperty(exports, 'RENDERER_TYPE', {
	enumerable: true,
	get: function () { return constants.RENDERER_TYPE; }
});
Object.defineProperty(exports, 'SAMPLER_TYPES', {
	enumerable: true,
	get: function () { return constants.SAMPLER_TYPES; }
});
Object.defineProperty(exports, 'SCALE_MODES', {
	enumerable: true,
	get: function () { return constants.SCALE_MODES; }
});
Object.defineProperty(exports, 'TARGETS', {
	enumerable: true,
	get: function () { return constants.TARGETS; }
});
Object.defineProperty(exports, 'TYPES', {
	enumerable: true,
	get: function () { return constants.TYPES; }
});
Object.defineProperty(exports, 'WRAP_MODES', {
	enumerable: true,
	get: function () { return constants.WRAP_MODES; }
});
Object.defineProperty(exports, 'ExtensionType', {
	enumerable: true,
	get: function () { return extensions.ExtensionType; }
});
exports.extensions = extensions.extensions;
exports.DEG_TO_RAD = _const.DEG_TO_RAD;
exports.PI_2 = _const.PI_2;
exports.RAD_TO_DEG = _const.RAD_TO_DEG;
Object.defineProperty(exports, 'SHAPES', {
	enumerable: true,
	get: function () { return _const.SHAPES; }
});
exports.groupD8 = groupD8.groupD8;
exports.Transform = Transform.Transform;
exports.Runner = runner.Runner;
Object.defineProperty(exports, 'UPDATE_PRIORITY', {
	enumerable: true,
	get: function () { return _const$1.UPDATE_PRIORITY; }
});
exports.Ticker = Ticker.Ticker;
exports.TickerPlugin = TickerPlugin.TickerPlugin;
exports.autoDetectRenderer = autoDetectRenderer.autoDetectRenderer;
exports.BackgroundSystem = BackgroundSystem.BackgroundSystem;
exports.BatchRenderer = BatchRenderer.BatchRenderer;
exports.Program = Program.Program;
exports.BatchSystem = BatchSystem.BatchSystem;
exports.ContextSystem = ContextSystem.ContextSystem;
exports.Filter = Filter.Filter;
exports.FilterSystem = FilterSystem.FilterSystem;
exports.BaseTexture = BaseTexture.BaseTexture;
exports.FramebufferSystem = FramebufferSystem.FramebufferSystem;
exports.MultisampleSystem = MultisampleSystem.MultisampleSystem;
exports.BufferSystem = BufferSystem.BufferSystem;
exports.GeometrySystem = GeometrySystem.GeometrySystem;
exports.MaskSystem = MaskSystem.MaskSystem;
exports.ScissorSystem = ScissorSystem.ScissorSystem;
exports.StencilSystem = StencilSystem.StencilSystem;
exports.PluginSystem = PluginSystem.PluginSystem;
exports.ProjectionSystem = ProjectionSystem.ProjectionSystem;
exports.ObjectRendererSystem = ObjectRendererSystem.ObjectRendererSystem;
exports.Renderer = Renderer.Renderer;
exports.GenerateTextureSystem = GenerateTextureSystem.GenerateTextureSystem;
exports.RenderTexturePool = RenderTexturePool.RenderTexturePool;
exports.RenderTextureSystem = RenderTextureSystem.RenderTextureSystem;
exports.ShaderSystem = ShaderSystem.ShaderSystem;
exports.StartupSystem = StartupSystem.StartupSystem;
exports.StateSystem = StateSystem.StateSystem;
exports.TextureGCSystem = TextureGCSystem.TextureGCSystem;
exports.TextureSystem = TextureSystem.TextureSystem;
exports.TransformFeedbackSystem = TransformFeedbackSystem.TransformFeedbackSystem;
exports.ViewSystem = ViewSystem.ViewSystem;
exports.VERSION = VERSION;
//# sourceMappingURL=index.js.map
